@@ -2,5 +2,11 @@ from dolang.version import __version_info__, __version__
 from dolang.yaml_tools import yaml
 
 from dolang.grammar import parse_string
-from dolang.grammar import stringify, list_variables, list_symbols, time_shift, steady_state
-from dolang.grammar import str_expression
\ No newline at end of file
+from dolang.grammar import (
+    stringify,
+    list_variables,
+    list_symbols,
+    time_shift,
+    steady_state,
+)
+from dolang.grammar import str_expression
